import React, { useState, useEffect, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import useKeepAlive from "@/components/useKeepAlive";
import getcolumns from "./columns";
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
function Dictionary() {
    let actionRef = useRef();
    const [drawer, setdrawer] = useState({
        open: false,
    });
    const { run, loading, runAsync } = useRequest(doFetch, {
        manual: true,
        onSuccess: (res, params) => {
            if (res?.code == '0000') {
                actionRef?.current?.reload();
                setdrawer((s) => ({
                    ...s,
                    open: false,
                }));
            }
        },
    });
    const columns = useMemo(() => {
        let defcolumn = getcolumns();
        return defcolumn.concat({
            title: "操作",
            valueType: "option",
            width: 80,
            render: (text, row, _, action) => rightExtra(text, row, _, action),
        });
    }, []);
    const rightExtra = (text, row, _, action) => {
        /**
     * type   1初始化   2自定义
     * isBasis 有无新增  1没有   2有
     */
        let ifs = row.type == 1,
            ifsc = row.isBasis == 2;
        return [
            ifs && ifsc && <PremButton
                key="add"
                btn={{
                    type:"primary",
                    size: "small",
                    onClick: () => {
                        setdrawer(s => {
                            return {
                                ...s,
                                open: true,
                                title: `新增 ${row.title} 下的数据字典`,
                                val: 'add',
                                item: row
                            }
                        })
                    },
                }}
            >
                新增
            </PremButton>,
            !ifs && <PremButton
                key="edit"
                btn={{
                    type: 'primary',
                    size: "small",
                    onClick: () => {
                        setdrawer(s => {
                            return {
                                ...s,
                                open: true,
                                title: `修改${row.title}`,
                                val: 'edit',
                                item: {
                                    ...row,
                                    dicName:row.title,
                                    dicDescription:row.description
                                }
                            }
                        })
                    },
                }}
            >
                修改
            </PremButton>,
            !ifs && <PremButton
                key='delete'
                pop={{
                    title: "是否删除该数据字典?",
                    okText: "确认",
                    cancelText: "取消",
                    onConfirm: async () => {
                        await runAsync({
                            url: "/ta_wms_base_business/sysDic/deleteById",
                            params: { id: row.key },
                        });
                    },
                }}
                btn={{
                    size: "small",
                    danger: true
                }}
            >
                删除
            </PremButton>
        ];
    };
    return <div>
        <AutoTable
            pagetitle='数据字典'
            columns={columns}
            path='/ta_wms_base_business/sysDic/queryTreeList'
            actionRef={actionRef}
            rowKey='key'
        />
        <DrawerPro
            {...drawer}
            fields={columns}
            defaultFormValue={drawer?.item}
            placement="right"
            onClose={() => {
                setdrawer((s) => ({
                    ...s,
                    open: false,
                }));
            }}
            onFinish={async (vals) => {
                let newfields = JSON.parse(JSON.stringify(vals));
                let difrid = drawer.val == "edit" ? { id: drawer.item.key } : { parentId: drawer.item.key };
                await runAsync({
                    url: "/ta_wms_base_business/sysDic/save",
                    params: { ...newfields, ...difrid },
                });
            }}
            width='60%'
        />
    </div>;
}

export default useKeepAlive(Dictionary);